@@ -31,11 +31,12 @@ Access to other functions is by method syntax, viz:
 
 =cut
 
-# Load the fundamental PDL packages, no imports
-# Because there are no imports, we do not need
-# the usual 'eval in the user's namespace' routine.
+package PDL::Lite;
 
-use PDL::Core '';
+use strict;
+use warnings;
+
+use PDL::Core qw(pdl piddle barf null);
 use PDL::Ops '';
 use PDL::Primitive '';
 use PDL::Ufunc '';
@@ -45,12 +46,11 @@ use PDL::Bad '';
 use PDL::Version ;  # Doesn't export anything - no need for ''
 use PDL::Lvalue;
 
-package PDL::Lite;
-$VERSION = $PDL::Version::VERSION;
+our $VERSION = $PDL::Version::VERSION;
 
-@ISA = qw( PDL::Exporter );
+our @ISA = qw( PDL::Exporter );
 
-@EXPORT = qw( piddle pdl null barf ); # Only stuff always exported!
+our @EXPORT = qw( piddle pdl null barf ); # Only stuff always exported!
 our %EXPORT_TAGS = (
    Func     => [@EXPORT],
 );
